HydrationLimits

Struct HydrationLimits 

pub struct HydrationLimits {
    pub max_in_flight_work: usize,
    pub max_in_flight_per_content: usize,
}
Bounded hydration work limits.

Fields

max_in_flight_work: usize

Maximum number of backend work items retained by one coordinator.

max_in_flight_per_content: usize

Maximum number of backend work items retained for one content key.

Implementations

Source

impl HydrationLimits

pub const DEFAULT: Self

Conservative defaults suitable for a provider process.