HydrationRequest

Struct HydrationRequest 

pub struct HydrationRequest { /* private fields */ }
One logical hydration request plus the physical alignment required by its adapter boundary.

Implementations

Source

impl HydrationRequest

pub const fn new( read: ContentReadRequest, alignment: Alignment, session_generation: SessionGeneration, ) -> Self

Creates a hydration request from an exact content read and physical transfer alignment.

pub const fn whole( key: CloudItemKey, revision: ContentRevision, expected_size: u64, session_generation: SessionGeneration, ) -> Self

Creates a complete-file hydration request.

pub const fn range( key: CloudItemKey, revision: ContentRevision, expected_size: u64, range: ByteRange, alignment: Alignment, session_generation: SessionGeneration, ) -> Self

Creates a range hydration request with adapter-owned physical alignment.

pub const fn read(&self) -> &ContentReadRequest

Returns the exact logical content request.

pub const fn alignment(&self) -> Alignment

Returns the physical range alignment owned by the active adapter boundary.

pub const fn session_generation(&self) -> SessionGeneration

Returns the platform session generation that owns this waiter and its completion.