pub struct MetadataRevision(/* private fields */);Expand description
Opaque equality/precondition token for metadata state.
Implementations
Sourceimpl MetadataRevision
impl MetadataRevision
Sourcepub fn new(value: impl Into<Vec<u8>>) -> Result<Self>
pub fn new(value: impl Into<Vec<u8>>) -> Result<Self>
Creates a non-empty opaque revision token.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
Sourcepub fn from_slice(value: &[u8]) -> Result<Self>
pub fn from_slice(value: &[u8]) -> Result<Self>
Copies a non-empty opaque revision token from a byte slice.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consumes the revision and returns its opaque bytes.