pub enum PersistedChangeBatchState {
Recorded,
EffectsReplayable,
}Expand description
Durable state of one pending change batch.
Variants
Recorded
Batch bytes and base checkpoint are durable, but effects may not yet be replayable.
EffectsReplayable
All effects needed after restart are durable and may be replayed idempotently.