PersistedChangeBatch

Struct PersistedChangeBatch 

pub struct PersistedChangeBatch { /* private fields */ }
Change batch persisted before its following cursor becomes active.

Implementations

Source

impl PersistedChangeBatch

pub const fn new( id: ChangeBatchId, scope: CloudScope, base_cursor: Option<ChangeCursor>, batch: ChangeBatch, ) -> Self

Creates the first durable form of a fetched change batch.

pub const fn id(&self) -> &ChangeBatchId

Returns the batch identity.

pub const fn scope(&self) -> &CloudScope

Returns the namespace/root checkpoint scope.

pub const fn base_cursor(&self) -> Option<&ChangeCursor>

Returns the active cursor from which this batch was fetched.

pub const fn batch(&self) -> &ChangeBatch

Returns the durable backend batch.

pub const fn state(&self) -> PersistedChangeBatchState

Returns whether replay prerequisites are durable.

pub fn mark_effects_replayable(&mut self) -> bool

Marks the batch effects replayable. The operation is idempotent.