pub enum ContentUploadRecordTransition {
Applied,
AlreadyApplied,
Fenced,
}Expand description
Result of an idempotent upload-record transition.
Variants
Applied
Durable state changed.
AlreadyApplied
Equivalent or later durable state already contains the transition.
Fenced
A newer durable offset or local generation superseded the transition.