ContentUploadSession

Struct ContentUploadSession 

pub struct ContentUploadSession { /* private fields */ }
Backend upload session and the next byte offset that remains to be sent.

Implementations

Source

impl ContentUploadSession

pub const fn new(id: ContentUploadSessionId, accepted_offset: u64) -> Self

Creates a backend upload-session checkpoint.

pub const fn id(&self) -> &ContentUploadSessionId

Returns the backend upload-session identity.

pub const fn accepted_offset(&self) -> u64

Returns the first local byte not yet accepted by the backend.

pub fn validate_for(&self, intent: &ContentUploadIntent) -> Result<()>

Validates that the backend checkpoint remains within the immutable snapshot.

Errors

Returns an error when validation fails or an underlying backend, store, or platform operation fails.