pub struct HydrationLimits {
pub max_in_flight_work: usize,
pub max_in_flight_per_content: usize,
}Expand description
Bounded hydration work limits.
Fields
max_in_flight_work: usizeMaximum number of backend work items retained by one coordinator.
max_in_flight_per_content: usizeMaximum number of backend work items retained for one content key.
Implementations