pub struct HydrationWaiter { /* private fields */ }Expand description
One registered hydration waiter that resolves to exactly its requested logical bytes.
Implementations
Sourceimpl HydrationWaiter
impl HydrationWaiter
Sourcepub fn cancellation_handle(&self) -> HydrationCancellationHandle
pub fn cancellation_handle(&self) -> HydrationCancellationHandle
Returns an independently cloneable cancellation handle for this waiter.
Sourcepub async fn wait(self) -> HydrationResult<ContentReadResponse>
pub async fn wait(self) -> HydrationResult<ContentReadResponse>
Drives shared backend work and returns only the exact logical bytes requested by this waiter.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.