pub enum MutationRemoteOutcome {
Committed {
item: Option<CloudItem>,
},
AlreadyCommitted {
item: Option<CloudItem>,
},
PreconditionFailed {
metadata_revision: Option<MetadataRevision>,
content_revision: Option<ContentRevision>,
},
RemoteOutcomeUnknown,
}Expand description
Product-neutral result of one conditional remote mutation.
Variants
Committed
The backend committed the requested effect during this attempt.
Fields
AlreadyCommitted
Reconciliation proved that an earlier attempt already committed the effect.
Fields
PreconditionFailed
One or more revision preconditions no longer match remote state.
Fields

metadata_revision: Option<MetadataRevision>Current metadata revision when known.

content_revision: Option<ContentRevision>Current content revision when known.
RemoteOutcomeUnknown
The transport result does not prove whether the backend committed the effect.