pub enum MutationRunOutcome {
Completed,
RemoteOutcomePending,
Fenced,
}Expand description
Stable outcome of one mutation-runner invocation.
Variants
Completed
Remote outcome, product/platform reconciliation, and completion are durable.
RemoteOutcomePending
Remote application may have committed, but reconciliation still has no known outcome.
Fenced
A newer active platform session fenced this executor before its next durable transition.