pub struct PersistedChangeBatch { /* private fields */ }Expand description
Change batch persisted before its following cursor becomes active.
Implementations
Sourceimpl PersistedChangeBatch
impl PersistedChangeBatch
Sourcepub const fn new(
id: ChangeBatchId,
scope: CloudScope,
base_cursor: Option<ChangeCursor>,
batch: ChangeBatch,
) -> Self
pub const fn new( id: ChangeBatchId, scope: CloudScope, base_cursor: Option<ChangeCursor>, batch: ChangeBatch, ) -> Self
Creates the first durable form of a fetched change batch.
Sourcepub const fn id(&self) -> &ChangeBatchId
pub const fn id(&self) -> &ChangeBatchId
Returns the batch identity.
Sourcepub const fn scope(&self) -> &CloudScope
pub const fn scope(&self) -> &CloudScope
Returns the namespace/root checkpoint scope.
Sourcepub const fn base_cursor(&self) -> Option<&ChangeCursor>
pub const fn base_cursor(&self) -> Option<&ChangeCursor>
Returns the active cursor from which this batch was fetched.
Sourcepub const fn batch(&self) -> &ChangeBatch
pub const fn batch(&self) -> &ChangeBatch
Returns the durable backend batch.
Sourcepub const fn state(&self) -> PersistedChangeBatchState
pub const fn state(&self) -> PersistedChangeBatchState
Returns whether replay prerequisites are durable.
Sourcepub fn mark_effects_replayable(&mut self) -> bool
pub fn mark_effects_replayable(&mut self) -> bool
Marks the batch effects replayable. The operation is idempotent.