pub struct ContentUploadChunkAck { /* private fields */ }Expand description
Backend acknowledgement of one exact upload chunk.
Implementations
Sourceimpl ContentUploadChunkAck
impl ContentUploadChunkAck
Sourcepub const fn new(
session_id: ContentUploadSessionId,
accepted_offset: u64,
) -> Self
pub const fn new( session_id: ContentUploadSessionId, accepted_offset: u64, ) -> Self
Creates an acknowledgement whose offset is validated by the submitted chunk.
Sourcepub const fn session_id(&self) -> &ContentUploadSessionId
pub const fn session_id(&self) -> &ContentUploadSessionId
Returns the backend upload-session identity.
Sourcepub const fn accepted_offset(&self) -> u64
pub const fn accepted_offset(&self) -> u64
Returns the first byte not yet accepted by the backend.
Sourcepub fn validate_for(&self, chunk: &ContentUploadChunk) -> Result<()>
pub fn validate_for(&self, chunk: &ContentUploadChunk) -> Result<()>
Validates exact, monotonic acknowledgement of the submitted chunk.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.