pub struct ContentUploadSession { /* private fields */ }Expand description
Backend upload session and the next byte offset that remains to be sent.
Implementations
Sourceimpl ContentUploadSession
impl ContentUploadSession
Sourcepub const fn new(id: ContentUploadSessionId, accepted_offset: u64) -> Self
pub const fn new(id: ContentUploadSessionId, accepted_offset: u64) -> Self
Creates a backend upload-session checkpoint.
Sourcepub const fn id(&self) -> &ContentUploadSessionId
pub const fn id(&self) -> &ContentUploadSessionId
Returns the backend upload-session identity.
Sourcepub const fn accepted_offset(&self) -> u64
pub const fn accepted_offset(&self) -> u64
Returns the first local byte not yet accepted by the backend.
Sourcepub fn validate_for(&self, intent: &ContentUploadIntent) -> Result<()>
pub fn validate_for(&self, intent: &ContentUploadIntent) -> Result<()>
Validates that the backend checkpoint remains within the immutable snapshot.
Errors
Returns an error when validation fails or an underlying backend, store, or platform operation fails.